
# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

"""
Worker for memory.
"""
#import psutil
from vsm import utils

class MemoryWorker(object):
    """Worker for Memory."""
    def __init__(self):
        pass

#    def get_mem_total(self):
#        mem = psutil.virtual_memory()
#        return mem.total

    #def get_mem_available(self):
    #    mem = psutil.virtual_memory()
    #    return mem.available



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from sqlalchemy import Boolean, Column, DateTime, ForeignKey
from sqlalchemy import Integer, MetaData, String, Table
from sqlalchemy import Table, Text, Float

def upgrade(migrate_engine):
    # Upgrade operations go here. Don't create your own engine;
    # bind migrate_engine to your metadata
    meta = MetaData()
    meta.bind = migrate_engine

    crushmaps = Table(
        'crushmaps', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('updated_at', DateTime(timezone=False)),
        Column('created_at', DateTime(timezone=False)),
        Column('deleted_at', DateTime(timezone=False)),
        Column('deleted', Boolean(create_constraint=True, name=None)),
        Column('content',
                Text(convert_unicode=False,
                    unicode_error=None, _warn_on_bytestring=False),
                nullable=False),
    )

    recipes = Table(
        'recipes', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('recipe_name', String(length=255), unique=True, nullable=False),
        Column('updated_at', DateTime(timezone=False)),
        Column('created_at', DateTime(timezone=False)),
        Column('deleted_at', DateTime(timezone=False)),
        Column('deleted', Boolean(create_constraint=True, name=None)),
        Column('pg_num', Integer, nullable=False),
        Column('pgp_num', Integer, nullable=False),
        Column('size', Integer, nullable=False),
        Column('min_size', Integer),
        Column('crush_ruleset', Integer, nullable=False),
        Column('crash_replay_interval', Integer),
    )

    vsm_capacity_manages = Table(
        'vsm_capacity_manages', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('name', String(length=255), nullable=False),
        Column('capacity_quota_mb', Integer),
        Column('capacity_used_mb', Integer),
        Column('updated_at', DateTime(timezone=False)),
        Column('created_at', DateTime(timezone=False)),
        Column('deleted_at', DateTime(timezone=False)),
        Column('deleted', Boolean(create_constraint=True, name=None)),
        Column('testyr', Integer),
    )

    try:
        crushmaps.create()
    except Exception:
        meta.drop_all(tables=[crushmaps])
        raise

    try:
        recipes.create()
    except Exception:
        meta.drop_all(tables=[recipes])
        raise

    try:
        vsm_capacity_manages.create()
    except Exception:
        meta.drop_all(tables=[vsm_capacity_manages])
        raise

def downgrade(migrate_engine):
    meta = MetaData()
    meta.bind = migrate_engine

    crushmaps = Table('crushmaps',
                        meta,
                        autoload=True)
    crushmaps.drop()

    recipes = Table('recipes',
                    meta,
                    autoload=True)
    recipes.drop()

    vsm_capacity_manages = Table('vsm_capacity_manages',
                                meta,
                                autoload=True)
    vsm_capacity_manages.drop()



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from sqlalchemy import and_, String, Column, MetaData, select, Table, Integer

def upgrade(migrate_engine):
    meta = MetaData()
    meta.bind = migrate_engine

    clusters = Table('clusters', meta, autoload=True)
    clusters.drop_column('primary_public_network')
    clusters.drop_column('secondary_public_network')
    clusters.drop_column("journal_size")
    clusters.drop_column("size")
    clusters.drop_column("osd_heartbeat_interval")
    clusters.drop_column("osd_heartbeat_grace")

    management_network = Column('management_network', String(length=255))
    ceph_public_network = Column('ceph_public_network', String(length=255))

    clusters.create_column(management_network)
    clusters.create_column(ceph_public_network)


def downgrade(migrate_engine):
    meta = MetaData()
    meta.bind = migrate_engine

    clusters = Table('clusters', meta, autoload=True)

    clusters.drop_column('management_network')
    clusters.drop_column('ceph_public_network')
    primary_public_network = Column('primary_public_network', String(length=255))
    secondary_public_network = Column('secondary_public_network', String(length=255))
    journal_size = Column(Integer, nullable=False)
    size = Column(Integer, nullable=True)
    osd_heartbeat_interval = Column('osd_heartbeat_interval',Integer, nullable=True)
    osd_heartbeat_grace=Column('osd_heartbeat_grace',Integer, nullable=True)

    clusters.create_column(primary_public_network)
    clusters.create_column(secondary_public_network)
    clusters.create_column(journal_size)
    clusters.create_column(size)
    clusters.create_column(osd_heartbeat_interval)
    clusters.create_column(osd_heartbeat_grace)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from sqlalchemy import Boolean, Column, DateTime
from sqlalchemy import Integer, MetaData, String, Table
from sqlalchemy import Table, Text

def upgrade(migrate_engine):
    # Upgrade operations go here. Don't create your own engine;
    # bind migrate_engine to your metadata
    meta = MetaData()
    meta.bind = migrate_engine

    try:
        long_calls = Table('long_calls',
                        meta,
                        autoload=True)
        long_calls.drop()
    except Exception:
        pass


def downgrade(migrate_engine):
    meta = MetaData()
    meta.bind = migrate_engine





# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2011 OpenStack Foundation.
# Copyright 2012, Red Hat, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
Exception related utilities.
"""

import contextlib
import logging
import sys
import traceback

from vsm.openstack.common.gettextutils import _

@contextlib.contextmanager
def save_and_reraise_exception():
    """Save current exception, run some code and then re-raise.

    In some cases the exception context can be cleared, resulting in None
    being attempted to be re-raised after an exception handler is run. This
    can happen when eventlet switches greenthreads or when running an
    exception handler, code raises and catches an exception. In both
    cases the exception context will be cleared.

    To work around this, we save the exception state, run handler code, and
    then re-raise the original exception. If another exception occurs, the
    saved exception is logged and the new exception is re-raised.
    """
    type_, value, tb = sys.exc_info()
    try:
        yield
    except Exception:
        logging.error(_('Original exception being dropped: %s'),
                      traceback.format_exception(type_, value, tb))
        raise
    raise type_, value, tb
